All Classes and Interfaces

Class
Description
 
 
 
The Collections class provides utility methods for creating optimized data structures such as maps, sets, and lists.
 
A custom exception that represents errors occurring during the execution or processing of commands in the application.
 
 
 
 
This exception is a subclass of RuntimeException and is typically used to signal scenarios where the required dependency for an operation or process cannot be found or resolved.
 
A custom exception that serves as a warning that a "forever" check should have been performed earlier in the workflow.
 
 
 
 
 
 
 
 
Provides utility methods for working with threads, including creating virtual threads, thread factories, and executors.
 
 
 
 
 
 
 
A custom exception that indicates a parsing error in the application.
Enum representing various Minecraft server platforms.
 
Represents the Minecraft Java Edition protocol version mapping table.
 
 
Utility class containing reflection-related methods for manipulating and inspecting classes and fields.
 
SimplePatcher is just an accidental byproduct, and I don't recommend anyone to use it.
The class is necessary to debug memory allocations via soft references.
 
 
The TimeParser class provides functionality for parsing time-related string inputs and performing operations such as calculating future times, validating time formats, and checking time conditions.
The TimeUnit enum represents various units of time, each of which can be used to perform time-based calculations on a LocalDateTime object.
 
Implementation of the Collection interface which: Stores elements using weak semantics (see WeakReference) Automatically reclaims storage for garbage collected elements Is NOT thread safe Is NOT RandomAccess, because garbage collector can remove element at any time Does NOT support null elements Please note that since weak references can be collected at any time, index-based methods (like get(index)) or size-based methods (like size()) are dangerous, misleading, error-inducing and are not supported.
A custom exception that indicates an operation involving an unsupported or invalid type.
This exception is a subclass of RuntimeException and is typically used to signal scenarios where a particular version of a component, resource, or specification cannot be processed or is not supported by the system.
 
 
 
 
The VersionComparator class provides utility methods for comparing software version strings.
Represents a version constraint that can evaluate whether specific versions satisfy its defined rules and conditions.
 
 
 
 
A Map-like data structure that uses primitive boolean keys and weakly references its values.
 
 
A Map-like data structure that uses primitive double keys and weakly references its values.
A Map-like data structure that uses primitive float keys and weakly references its values.
 
A Map-like data structure that uses primitive int keys and weakly references its values.
 
 
Implementation of the Collection interface which: Stores elements using weak semantics (see WeakReference) Automatically reclaims storage for garbage collected elements Is thread safe Is NOT RandomAccess, because garbage collector can remove element at any time Does NOT support null elements Please note that since weak references can be collected at any time, index-based methods (like get(index)) or size-based methods (like size()) are dangerous, misleading, error-inducing and are not supported.
A Map-like data structure that uses primitive long keys and weakly references its values.
A Map-like data structure that uses weakly referenced Object keys and primitive boolean values.
A Map-like data structure that uses weakly referenced Object keys and primitive double values.
A Map-like data structure that uses weakly referenced Object keys and primitive float values.
A Map-like data structure that uses weakly referenced Object keys and primitive int values.
A Map-like data structure that uses weakly referenced Object keys and primitive long values.