Record Class MavenLocalRepositoryLocator.RepositoryInfo

java.lang.Object
java.lang.Record
one.pkg.tinyutils.maven.MavenLocalRepositoryLocator.RepositoryInfo
Enclosing class:
MavenLocalRepositoryLocator

public static record MavenLocalRepositoryLocator.RepositoryInfo(String absolutePath, boolean exists, boolean read, boolean write, long size) extends Record
  • Constructor Summary

    Constructors
    Constructor
    Description
    RepositoryInfo(String absolutePath, boolean exists, boolean read, boolean write, long size)
    Creates an instance of a RepositoryInfo record class.
  • Method Summary

    Modifier and Type
    Method
    Description
    Returns the value of the absolutePath record component.
    final boolean
    Indicates whether some other object is "equal to" this one.
    boolean
    Returns the value of the exists record component.
     
    final int
    Returns a hash code value for this object.
    boolean
    Returns the value of the read record component.
    long
    Returns the value of the size record component.
    final String
    Returns a string representation of this record class.
    boolean
    Returns the value of the write record component.

    Methods inherited from class java.lang.Object

    clone, finalize, getClass, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • RepositoryInfo

      public RepositoryInfo(String absolutePath, boolean exists, boolean read, boolean write, long size)
      Creates an instance of a RepositoryInfo record class.
      Parameters:
      absolutePath - the value for the absolutePath record component
      exists - the value for the exists record component
      read - the value for the read record component
      write - the value for the write record component
      size - the value for the size record component
  • Method Details

    • formatSize

      public String formatSize()
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared with Objects::equals(Object,Object); primitive components are compared with '=='.
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • absolutePath

      public String absolutePath()
      Returns the value of the absolutePath record component.
      Returns:
      the value of the absolutePath record component
    • exists

      public boolean exists()
      Returns the value of the exists record component.
      Returns:
      the value of the exists record component
    • read

      public boolean read()
      Returns the value of the read record component.
      Returns:
      the value of the read record component
    • write

      public boolean write()
      Returns the value of the write record component.
      Returns:
      the value of the write record component
    • size

      public long size()
      Returns the value of the size record component.
      Returns:
      the value of the size record component