Package one.pkg.tinyutils.parse.resource
Class ResourceParser
java.lang.Object
one.pkg.tinyutils.parse.resource.ResourceParser
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic @Nullable InputStreamstatic InputStreamRetrieves an InputStream for a specified resource file by its filename.
-
Constructor Details
-
ResourceParser
public ResourceParser()
-
-
Method Details
-
resource
Retrieves an InputStream for a specified resource file by its filename.- Parameters:
filename- the name of the resource file to be loaded- Returns:
- an InputStream for the resource file, or null if the resource cannot be found or accessed
-
resource
@Nullable public static @Nullable InputStream resource(@NotNull @NotNull Class<?> clazz, @NotNull @NotNull String filename)
-