Record Class VolumeControl.VolumeInfo

java.lang.Object
java.lang.Record
one.pkg.tinyutils.sounds.VolumeControl.VolumeInfo
Enclosing class:
VolumeControl

public static record VolumeControl.VolumeInfo(float volume, float volumeDb, float minDb, float maxDb, boolean muted) extends Record
  • Constructor Summary

    Constructors
    Constructor
    Description
    VolumeInfo(float volume, float volumeDb, float minDb, float maxDb, boolean muted)
    Creates an instance of a VolumeInfo record class.
  • Method Summary

    Modifier and Type
    Method
    Description
    final boolean
    Indicates whether some other object is "equal to" this one.
    final int
    Returns a hash code value for this object.
    float
    Returns the value of the maxDb record component.
    float
    Returns the value of the minDb record component.
    boolean
    Returns the value of the muted record component.
    final String
    Returns a string representation of this record class.
    float
    Returns the value of the volume record component.
    float
    Returns the value of the volumeDb record component.

    Methods inherited from class java.lang.Object

    clone, finalize, getClass, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • VolumeInfo

      public VolumeInfo(float volume, float volumeDb, float minDb, float maxDb, boolean muted)
      Creates an instance of a VolumeInfo record class.
      Parameters:
      volume - the value for the volume record component
      volumeDb - the value for the volumeDb record component
      minDb - the value for the minDb record component
      maxDb - the value for the maxDb record component
      muted - the value for the muted record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with '=='.
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • volume

      public float volume()
      Returns the value of the volume record component.
      Returns:
      the value of the volume record component
    • volumeDb

      public float volumeDb()
      Returns the value of the volumeDb record component.
      Returns:
      the value of the volumeDb record component
    • minDb

      public float minDb()
      Returns the value of the minDb record component.
      Returns:
      the value of the minDb record component
    • maxDb

      public float maxDb()
      Returns the value of the maxDb record component.
      Returns:
      the value of the maxDb record component
    • muted

      public boolean muted()
      Returns the value of the muted record component.
      Returns:
      the value of the muted record component