Enum Class SystemInfo.STDLIB

java.lang.Object
java.lang.Enum<SystemInfo.STDLIB>
one.pkg.tinyutils.system.SystemInfo.STDLIB
All Implemented Interfaces:
Serializable, Comparable<SystemInfo.STDLIB>, Constable
Enclosing class:
SystemInfo

public static enum SystemInfo.STDLIB extends Enum<SystemInfo.STDLIB>
  • Enum Constant Details

  • Method Details

    • values

      public static SystemInfo.STDLIB[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static SystemInfo.STDLIB valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getInstances

      public static SystemInfo.STDLIB[] getInstances()
    • is

      public static boolean is(SystemInfo.STDLIB stdlib)