Record Class MemoryInfo

java.lang.Object
java.lang.Record
one.pkg.tinyutils.system.info.MemoryInfo

public record MemoryInfo(long current, long total) extends Record
  • Constructor Details

    • MemoryInfo

      public MemoryInfo(long current, long total)
      Creates an instance of a MemoryInfo record class.
      Parameters:
      current - the value for the current record component
      total - the value for the total record component
  • Method Details

    • getSystemInstance

      public static MemoryInfo getSystemInstance()
    • getJvmInstance

      public static MemoryInfo getJvmInstance()
    • format

      public String format()
    • formatFull

      public String formatFull(MemoryInfo.Type type)
    • full

      public long full(MemoryInfo.Type type)
    • formatCurrent

      public String formatCurrent(MemoryInfo.Type type)
    • current

      public long current(MemoryInfo.Type type)
    • getUsagePercentage

      public double getUsagePercentage()
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with '=='.
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • current

      public long current()
      Returns the value of the current record component.
      Returns:
      the value of the current record component
    • total

      public long total()
      Returns the value of the total record component.
      Returns:
      the value of the total record component