Enum Class STDLIB

java.lang.Object
java.lang.Enum<STDLIB>
one.pkg.tinyutils.system.info.STDLIB
All Implemented Interfaces:
Serializable, Comparable<STDLIB>, Constable

public enum STDLIB extends Enum<STDLIB>
  • Enum Constant Details

    • Musl

      public static final STDLIB Musl
    • MSVC

      public static final STDLIB MSVC
    • GNU

      public static final STDLIB GNU
    • Bionic

      public static final STDLIB Bionic
    • LibSystem

      public static final STDLIB LibSystem
    • UClibc

      public static final STDLIB UClibc
    • NewLib

      public static final STDLIB NewLib
  • Method Details

    • values

      public static STDLIB[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static STDLIB valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getInstances

      public static STDLIB[] getInstances()
    • is

      public static boolean is(STDLIB stdlib)