Record Class VirtualizationDetectionResult

java.lang.Object
java.lang.Record
one.pkg.tinyutils.system.info.VirtualizationDetectionResult

public record VirtualizationDetectionResult(VirtualizationType type, boolean isVirtualized, Map<String,String> details, List<String> detectionMethods) extends Record
  • Constructor Details

    • VirtualizationDetectionResult

      public VirtualizationDetectionResult(VirtualizationType type, boolean isVirtualized, Map<String,String> details, List<String> detectionMethods)
      Creates an instance of a VirtualizationDetectionResult record class.
      Parameters:
      type - the value for the type record component
      isVirtualized - the value for the isVirtualized record component
      details - the value for the details record component
      detectionMethods - the value for the detectionMethods record component
  • Method Details

    • toString

      @NotNull public @NotNull String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared with Objects::equals(Object,Object); primitive components are compared with '=='.
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • type

      public VirtualizationType type()
      Returns the value of the type record component.
      Returns:
      the value of the type record component
    • isVirtualized

      public boolean isVirtualized()
      Returns the value of the isVirtualized record component.
      Returns:
      the value of the isVirtualized record component
    • details

      public Map<String,String> details()
      Returns the value of the details record component.
      Returns:
      the value of the details record component
    • detectionMethods

      public List<String> detectionMethods()
      Returns the value of the detectionMethods record component.
      Returns:
      the value of the detectionMethods record component