Package one.pkg.tinyutils.maven
Record Class MavenLocalRepositoryLocator.RepositoryInfo
java.lang.Object
java.lang.Record
one.pkg.tinyutils.maven.MavenLocalRepositoryLocator.RepositoryInfo
- Enclosing class:
- MavenLocalRepositoryLocator
-
Constructor Summary
ConstructorsConstructorDescriptionRepositoryInfo(String absolutePath, boolean exists, boolean read, boolean write, long size) Creates an instance of aRepositoryInforecord class. -
Method Summary
Modifier and TypeMethodDescriptionReturns the value of theabsolutePathrecord component.final booleanIndicates whether some other object is "equal to" this one.booleanexists()Returns the value of theexistsrecord component.final inthashCode()Returns a hash code value for this object.booleanread()Returns the value of thereadrecord component.longsize()Returns the value of thesizerecord component.final StringtoString()Returns a string representation of this record class.booleanwrite()Returns the value of thewriterecord component.
-
Constructor Details
-
RepositoryInfo
Creates an instance of aRepositoryInforecord class.- Parameters:
absolutePath- the value for theabsolutePathrecord componentexists- the value for theexistsrecord componentread- the value for thereadrecord componentwrite- the value for thewriterecord componentsize- the value for thesizerecord component
-
-
Method Details
-
formatSize
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared withObjects::equals(Object,Object); primitive components are compared with '=='. -
absolutePath
Returns the value of theabsolutePathrecord component.- Returns:
- the value of the
absolutePathrecord component
-
exists
public boolean exists()Returns the value of theexistsrecord component.- Returns:
- the value of the
existsrecord component
-
read
public boolean read()Returns the value of thereadrecord component.- Returns:
- the value of the
readrecord component
-
write
public boolean write()Returns the value of thewriterecord component.- Returns:
- the value of the
writerecord component
-
size
public long size()Returns the value of thesizerecord component.- Returns:
- the value of the
sizerecord component
-