Package one.pkg.tinyutils.system.info
Record Class VirtualizationDetectionResult
java.lang.Object
java.lang.Record
one.pkg.tinyutils.system.info.VirtualizationDetectionResult
-
Constructor Summary
ConstructorsConstructorDescriptionVirtualizationDetectionResult(VirtualizationType type, boolean isVirtualized, Map<String, String> details, List<String> detectionMethods) Creates an instance of aVirtualizationDetectionResultrecord class. -
Method Summary
Modifier and TypeMethodDescriptiondetails()Returns the value of thedetailsrecord component.Returns the value of thedetectionMethodsrecord component.final booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.booleanReturns the value of theisVirtualizedrecord component.@NotNull StringtoString()Returns a string representation of this record class.type()Returns the value of thetyperecord component.
-
Constructor Details
-
VirtualizationDetectionResult
public VirtualizationDetectionResult(VirtualizationType type, boolean isVirtualized, Map<String, String> details, List<String> detectionMethods) Creates an instance of aVirtualizationDetectionResultrecord class.- Parameters:
type- the value for thetyperecord componentisVirtualized- the value for theisVirtualizedrecord componentdetails- the value for thedetailsrecord componentdetectionMethods- the value for thedetectionMethodsrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared withObjects::equals(Object,Object); primitive components are compared with '=='. -
type
Returns the value of thetyperecord component.- Returns:
- the value of the
typerecord component
-
isVirtualized
public boolean isVirtualized()Returns the value of theisVirtualizedrecord component.- Returns:
- the value of the
isVirtualizedrecord component
-
details
Returns the value of thedetailsrecord component.- Returns:
- the value of the
detailsrecord component
-
detectionMethods
Returns the value of thedetectionMethodsrecord component.- Returns:
- the value of the
detectionMethodsrecord component
-